<?php

use  PRAMADILLO\Woocommerce_Pay_Per_Post_Restrict_Content ;
/**
 * Class Woocommerce_Pay_Per_Post_Shortcodes
 */
class Woocommerce_Pay_Per_Post_Shortcodes
{
    public static function register_shortcodes()
    {
        add_shortcode( 'woocommerce-payperpost', [ __CLASS__, 'process_shortcode' ] );
    }
    
    public static function process_shortcode( $atts )
    {
        $template = 'purchased';
        $orderby = 'post_date';
        $order = 'DESC';
        $product_ids = [];
        if ( isset( $atts['template'] ) && array_key_exists( $atts['template'], self::available_templates() ) ) {
            $template = $atts['template'];
        }
        $custom_post_types = get_option( WC_PPP_SLUG . '_custom_post_types', array() );
        $custom_post_types = ( empty($custom_post_types) ? array() : $custom_post_types );
        if ( !is_array( $custom_post_types ) ) {
            $custom_post_types = explode( ',', $custom_post_types );
        }
        $args = array(
            'orderby'     => $orderby,
            'order'       => $order,
            'nopaging'    => true,
            'meta_query'  => array( array(
            'key'     => WC_PPP_SLUG . '_product_ids',
            'value'   => '',
            'compare' => '!=',
        ) ),
            'post_status' => 'publish',
            'post_type'   => $custom_post_types,
        );
        Woocommerce_Pay_Per_Post_Helper::logger( print_r( $args, true ) );
        // Get all posts that are protected by WC PPP.  We do this by checking to see if they have a product_ids associated with post.
        $get_ppp_args = apply_filters( 'wc_pay_per_post_args', $args );
        $ppp_posts = get_posts( $get_ppp_args );
        ob_start();
        switch ( $template ) {
            case 'purchased':
                self::shortcode_purchased( $template, $ppp_posts );
                break;
            case 'remaining':
                self::shortcode_remaining( $template, $ppp_posts );
                break;
            case 'all':
                self::shortcode_all( $template, $ppp_posts );
                break;
        }
        return ob_get_clean();
    }
    
    private static function available_templates()
    {
        return [
            'purchased' => 'shortcode-purchased.php',
            'all'       => 'shortcode-all.php',
            'remaining' => 'shortcode-remaining.php',
        ];
    }
    
    /**
     * @param $template
     * @param $ppp_posts
     */
    protected static function shortcode_purchased( $template, $ppp_posts )
    {
        $purchased = [];
        
        if ( is_user_logged_in() ) {
            foreach ( $ppp_posts as $post ) {
                //				echo '<pre>';
                //				echo $post->post_title . '<br>';
                //				echo '</pre>';
                if ( self::has_access( $post->ID ) ) {
                    $purchased[] = $post;
                }
            }
            $template_file = ( locate_template( WC_PPP_TEMPLATE_PATH . self::available_templates()[$template] ) ?: WC_PPP_PATH . 'public/partials/' . self::available_templates()[$template] );
            require $template_file;
        }
    
    }
    
    /**
     * @param $template
     * @param $ppp_posts
     */
    protected static function shortcode_remaining( $template, $ppp_posts )
    {
        $remaining = [];
        
        if ( is_user_logged_in() ) {
            foreach ( $ppp_posts as $post ) {
                if ( !self::has_access( $post->ID ) ) {
                    $remaining[] = $post;
                }
            }
            $template_file = ( locate_template( WC_PPP_TEMPLATE_PATH . self::available_templates()[$template] ) ?: WC_PPP_PATH . 'public/partials/' . self::available_templates()[$template] );
            require $template_file;
        }
    
    }
    
    /**
     * @param $template
     * @param $ppp_posts
     */
    protected static function shortcode_all( $template, $ppp_posts )
    {
        $template_file = ( locate_template( WC_PPP_TEMPLATE_PATH . self::available_templates()[$template] ) ?: WC_PPP_PATH . 'public/partials/' . self::available_templates()[$template] );
        require $template_file;
    }
    
    /**
     * @param null $post_id
     *
     * @return bool
     */
    protected static function has_purchased_products( $post_id = null )
    {
        if ( is_null( $post_id ) ) {
            $post_id = get_the_ID();
        }
        $product_ids = array();
        $product_ids = get_post_meta( $post_id, WC_PPP_SLUG . '_product_ids', true );
        $current_user = wp_get_current_user();
        foreach ( (array) $product_ids as $id ) {
            Woocommerce_Pay_Per_Post_Helper::logger( 'Looking to see if purchased product ' . trim( $id ) );
            if ( wc_customer_bought_product( $current_user->user_email, $current_user->ID, trim( $id ) ) ) {
                return true;
            }
        }
        return false;
    }
    
    /**
     * @param $post_id
     *
     * This returns the INVERSE of can_user_view_content()
     * @return bool
     */
    protected static function has_access( $post_id )
    {
        $restrict = new Woocommerce_Pay_Per_Post_Restrict_Content( $post_id );
        return !$restrict->can_user_view_content();
    }

}